summaryrefslogtreecommitdiff
path: root/build/import-synthesis-xml.sh
diff options
context:
space:
mode:
Diffstat (limited to 'build/import-synthesis-xml.sh')
-rwxr-xr-xbuild/import-synthesis-xml.sh7
1 files changed, 5 insertions, 2 deletions
diff --git a/build/import-synthesis-xml.sh b/build/import-synthesis-xml.sh
index fc73b930..131e1f8c 100755
--- a/build/import-synthesis-xml.sh
+++ b/build/import-synthesis-xml.sh
@@ -4,7 +4,7 @@
# syncevolution git repository. Pass the path
# to a synthesis repository (default: ../libsynthesis).
#
# The script switches to the "synthesis" branch
# in the syncevolution repo and then merges all
# patches committed to the "master" branch in the
# synthesis repo, updating the "synthesis" branch
@@ -17,4 +17,7 @@
set -e
set -x
-`dirname $0`/import-foreign-git.sh "${1:-../libsynthesis}" synthesis src 3 src/sysync_SDK/configs/syncclient_sample_config.xml
+path="${1:-../libsynthesis}"
+files="`cd $path && find src/sysync_SDK/configs/ \( -name '*.xml' -o -name 'update-samples.pl' -o -name README \) -a \! \( -name 'sync*_sample_config.xml' -o -name sunbird_client.xml \)`"
+
+`dirname $0`/import-foreign-git.sh "${1:-../libsynthesis}" synthesis-xml-fragments src/syncevo/configs 3 $files
@@ -4,7 +4,7 @@
# to a synthesis repository (default: ../libsynthesis).
#
-# The script switches to the "synthesis" branch
+# The script switches to the "synthesis-xml-fragments" branch
# in the syncevolution repo and then merges all
# patches committed to the "master" branch in the